@@ -14,6 +14,7 @@ class Payment extends Component {
         this.state = {
             loading: true
         };
+        this.formRef = React.createRef();
     }
 
     componentDidMount() {
@@ -42,6 +43,7 @@ class Payment extends Component {
                 const bookingId = response.data;
                 this.props.addBooking(bookingId);
                 this.setState({ loading: false });
+                this.redirectWorldPay();
             })
             .catch(error => {
                 toast.error(error.response.data);
@@ -50,15 +52,29 @@ class Payment extends Component {
             });
     };
 
+    redirectWorldPay = () => {
+        const form = this.formRef.current;
+        form.submit();
+    };
+
     render() {
         return (
             <div className="choose-journey">
-                {this.loading && <Loader type="Oval" width={50} height={50} color="#088584" />}
-
+                <Loader type="Oval" width={50} height={50} color="#088584" />
                 {this.props.bookingId !== null && (
                     <>
                         <h1>Payment</h1>
-                        Order has been created, ready for payment.
+                        <form
+                            action="https://secure-test.worldpay.com/wcc/purchase"
+                            method="POST"
+                            ref={this.formRef}>
+                            <input type="hidden" name="testMode" value="100" />
+                            <input type="hidden" name="instId" value="1357697" />
+                            <input type="hidden" name="cartId" value={this.props.bookingId} />
+                            <input type="hidden" name="amount" value={this.props.price} />
+                            <input type="hidden" name="currency" value="GBP" />
+                            {/* <input type="submit" value=" Buy This " /> */}
+                        </form>
                     </>
                 )}
             </div>
@@ -70,6 +86,7 @@ const mapStateToProps = state => {
     const { outbound, inbound, addons, inCart } = state.cart;
     const seats = getTotalSeatsFromCart(state);
     const price = getTotalCostFromCart(state);
+
     return {
         bookingId: state.booking.bookingId,
         user: state.user,
@@ -81,6 +98,7 @@ const mapStateToProps = state => {
         price
     };
 };
+
 export default connect(
     mapStateToProps,
     { addBooking }
